Skip to contents

Print method for summary of model importance score table

Usage

# S3 method for class 'summary.model_imp_tbl'
print(x, ...)

Arguments

x

An object of class summary.model_imp_tbl.

...

Additional arguments passed to the print method.

Value

x, returned invisibly. Called for its side effect of printing a human-readable summary (number of models and tasks, and the top-scoring model for a subset of tasks) to the console.